unit BDETable;

interface

uses SysUtils, DbiTypes, DbiProcs, Classes, DsgnIntf, DB, DBCtrls;

type

{ TDatabaseList }

  TDatabaseList = class(TDBDataSet)
  protected
    function CreateHandle: HDBICur; override;
  end;

{ TUserList }

  TUserList = class(TDBDataSet)
  protected
    function CreateHandle: HDBICur; override;
  end;

{ TDriverList }

  TDriverList = class(TDBDataSet)
  protected
    function CreateHandle: HDBICur; override;
  end;

{ TTableList }

  TTableList = class(TDBDataSet)
  private
    FExtended: Boolean;
    FSystemTables: Boolean;
  protected
    function CreateHandle: HDBICur; override;
  published
    property ExtendedInfo: Boolean read FExtended write FExtended;
    property SystemTables: Boolean read FSystemTables write FSystemTables;
  end;

{ TTableItems }

  TTableItems = class(TDBDataSet)
  private
    FTableName: TFileName;
    procedure SetTableName(const Value: TFileName);
  published
    property TableName: TFileName read FTableName write SetTableName;
  end;

{ TFieldList }

  TFieldList = class(TTableItems)
  private
   FPhyType: boolean;
  protected
    function CreateHandle: HDBICur; override;
  published
    property PhyType: boolean read FPhyType write FPhyType default False;
  end;

{ TSecurityList }

  TSecurityList = class(TTableItems)
  protected
    function CreateHandle: HDBICur; override;
  end;

{ TFamilyList }

  TFamilyList = class(TTableItems)
  protected
    function CreateHandle: HDBICur; override;
  end;

{ TIndexList }

  TIndexList = class(TTableItems)
  protected
    function CreateHandle: HDBICur; override;
  end;

{ TRefIntList }

  TRefIntList = class(TTableItems)
  protected
    function CreateHandle: HDBICur; override;
  end;

{ TValCheckList }

  TValCheckList = class(TTableItems)
  protected
    function CreateHandle: HDBICur; override;
  end;

{ TLangDrivList }

  TLangDrivList = class(TDataSet)
  protected
    function CreateHandle: HDBICur; override;
  end;

{ TStoredProcList }

  TStoredProcList = class(TDBDataSet)
  private
    FExtended: Boolean;
    FSystemProcs: Boolean;
  protected
    function CreateHandle: HDBICur; override;
  published
    property ExtendedInfo: Boolean read FExtended write FExtended;
    property SystemProcs: Boolean read FSystemProcs write FSystemProcs;
  end;

{ TDatabaseDesc }

  TDatabaseDesc = class(TObject)
  private
    FDescription: DBDesc;
  public
    property Description: DBDesc read FDescription;
    constructor Create(DataBaseName: string);
  end;

{ TDriverDesc }

  TDriverDesc = class(TObject)
  private
    FDescription: DRVType;
  public
    property Description: DRVType read FDescription;
    constructor Create(DriverType: string);
  end;

implementation

uses Controls, WinProcs, WinTypes;

{ TDatabaseList }

function TDatabaseList.CreateHandle: HDBICur;
begin
  Check(DbiOpenDatabaseList(Result));
end;

{ TUserList }

function TUserList.CreateHandle: HDBICur;
begin
  Check(DbiOpenUserList(Result));
end;

{ TDriverList }

function TDriverList.CreateHandle: HDBICur;
begin
  Check(DbiOpenDriverList(Result));
end;

{ TTableList }

function TTableList.CreateHandle: HDBICur;
begin
  Check(DbiOpenTableList(DBHandle, ExtendedInfo, SystemTables, nil, Result));
end;

{ TTableItems }

procedure TTableItems.SetTableName(const Value: TFileName);
begin
  if Active then
   begin
    Active:=False;
    FTableName:=Value;
    Active:=True;
    DataEvent(dePropertyChange, 0);
   end
  else
   FTableName:=Value;
end;

{ TFieldList }

function TFieldList.CreateHandle: HDBICur;
var
  STableName: array[0..SizeOf(TFileName) - 1] of Char;
begin
  Check(DbiOpenFieldList(DBHandle, AnsiToNative(DBLocale, FTableName,
    STableName, Sizeof (STableName)), nil, FPhyType, Result));
end;

{ TSecurityList }

function TSecurityList.CreateHandle: HDBICur;
var
  STableName: array[0..SizeOf(TFileName) - 1] of Char;
begin
  Check(DbiOpenSecurityList(DBHandle, AnsiToNative(DBLocale, FTableName,
    STableName, Sizeof (STableName)), nil, Result));
end;

{ TFamilyList }

function TFamilyList.CreateHandle: HDBICur;
var
  STableName: array[0..SizeOf(TFileName) - 1] of Char;
begin
  Check(DbiOpenFamilyList(DBHandle, AnsiToNative(DBLocale, FTableName,
    STableName, Sizeof (STableName)), nil, Result));
end;

{ TIndexList }

function TIndexList.CreateHandle: HDBICur;
var
  STableName: array[0..SizeOf(TFileName) - 1] of Char;
begin
  Check(DbiOpenIndexList(DBHandle, AnsiToNative(DBLocale, FTableName,
    STableName, Sizeof (STableName)), nil, Result));
end;

{ TRefIntList }

function TRefIntList.CreateHandle: HDBICur;
var
  STableName: array[0..SizeOf(TFileName) - 1] of Char;
begin
  Check(DbiOpenRIntList(DBHandle, AnsiToNative(DBLocale, FTableName,
    STableName, Sizeof (STableName)), nil, Result));
end;

{ TValCheckList }

function TValCheckList.CreateHandle: HDBICur;
var
  STableName: array[0..SizeOf(TFileName) - 1] of Char;
begin
  Check(DbiOpenVChkList(DBHandle, AnsiToNative(DBLocale, FTableName,
    STableName, Sizeof (STableName)), nil, Result));
end;

{ TLangDrivList }

function TLangDrivList.CreateHandle: HDBICur;
begin
  Check(DbiOpenLdList(Result));
end;

{ TStoredProcList }

function TStoredProcList.CreateHandle: HDBICur;
begin
  if DataBase.IsSQLBased then
    Check(DbiOpenSPList(DBHandle, ExtendedInfo, SystemProcs, nil, Result))
{  else
    DatabaseError(GetExtStr(SLocalDatabase));}
end;

{ TDatabaseDesc }

constructor TDatabaseDesc.Create(DataBaseName: String);
var
  Buffer: PChar;
  BufLen: Word;
begin
  BufLen := Length(DatabaseName) + 1;
  Buffer := AllocMem(BufLen);
  try
    StrPCopy(Buffer, DatabaseName);
    Check(DbiGetDatabaseDesc(Buffer, @FDescription));
  finally
    FreeMem(Buffer, BufLen);
  end;
end;

{ TDriverDesc }

constructor TDriverDesc.Create(DriverType: String);
var
  Buffer: PChar;
  BufLen: Word;
begin
  BufLen := Length(DriverType) + 1;
  Buffer := AllocMem(BufLen);
  try
    StrPCopy(Buffer, DriverType);
    Check(DbiGetDriverDesc(Buffer, FDescription));
  finally
    FreeMem(Buffer, BufLen);
  end;
end;

end.
